@@ -33,10 +33,10 @@ public:  // methods
 
 private:  // methods
 
-    virtual void print(std::ostream& out) const override;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
+    void print(std::ostream& out) const override;
+    bool expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& request) const override;
 
-    std::vector<Type*> types_;
+    std::vector<std::pair<std::unique_ptr<Context>, Type*>> types_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
